
/**
 * @author wfyfngu
 * @create Apri 25, 2008
 */


/**
 * @namespace RINDEX
 */
if (typeof RINDEX == 'undefined') 
    RINDEX = {};

/**
 * @namespace RINDEX.Widget
 */
if (typeof RINDEX.Widget == 'undefined') 
    RINDEX.Widget = {};


/**
 * RINDEX 控件公共实用类
 * @class RINDEX.Utility
 * @static
 */
RINDEX.Utility = {

    /**
     * 获取一个值，该值指示当前的浏览器是否是IE
     * @field isIE
     * @type Boolean
     */
    isIE: document.all ? true : false,
    
    /**
     * 获取一个 HTML 元素
     * @method getObject
     * @param obj {HTMLElement || String} 要获取的元素或元素的ID
     * @return HTMLElement
     */
    getObject: function(obj){
        if (typeof obj == 'string') {
            if (this.isIE) 
                obj = document.all(obj);
            else 
                obj = document.getElementById(obj);
        }
        return obj;
    },
    
    /**
     * 生成具有指定标签的 HTML 元素
     * @method createObject
     * @param tag {String} 要生成的元素的标签
     * @param id {String || Null} 生成的元素的ID
     * @return HTMLElement
     */
    createObject: function(tag, id){
        var obj = document.createElement(tag);
        if (obj) {
            if (id != null) 
                obj.id = id;
            return obj;
        }
        //return document.body;
        return null;
    },
    
    /**
     * 追加指定的 CSS 样式到目标 HTML 对象
     * @method addCSS
     * @param obj {HTMLElement} 要追加样式的目标对象
     * @param className {String} CSS 样式名称
     * @return void
     */
    addCSS: function(obj, className){
        try {
            var css = obj.className;
            var index = css.indexOf(className);
            if (index < 0) 
                css += ' ' + className;
            
            obj.className = css;
        } 
        catch (e) {
            // TODO : 删除下一行
            confirm('Exception:' + e);
        }
    },
    
    /**
     * 从目标 HTML 对象删除指定的 CSS 样式
     * @method addCSS
     * @param obj {HTMLElement} 要删除样式的目标对象
     * @param className {String} CSS 样式名称
     * @return void
     */
    removeCSS: function(obj, className){
        try {
            var css = obj.className;
            var cssArr = css.split(' ');
            
            var nwCss = '';
            
            for (var i = 0; i < cssArr.length; i++) {
                if (cssArr[i] == className) 
                    continue;
                nwCss += cssArr[i] + ' ';
            }
            
            obj.className = nwCss;
            
        } 
        catch (e) {
            // TODO : 删除下一行
            confirm('Exception:' + e);
        }
    },
    
    /**
     * 使用指定的数值格式化表格
     * @method formatTable
     * @param tableObject {HtmlTableElement} 要格式化的表格
     * @param border {Number} 表格的边框宽度
     * @param cellSpacing {Number} 表格单元格的间距
     * @param cellPadding {Number} 表格中单元格的边距
     * @param align {String} 表格的对齐方式
     * @return void
     */
    formatTable: function(tableObject, border, cellSpacing, cellPadding, align){
        if (border == null || isNaN(parseInt(border))) 
            border = 0;
        else 
            border = parseInt(border);
        
        if (cellSpacing == null || isNaN(parseInt(cellSpacing))) 
            cellSpacing = 0;
        else 
            cellSpacing = parseInt(border);
        
        if (cellPadding == null || isNaN(parseInt(cellPadding))) 
            cellPadding = 0;
        else 
            cellPadding = parseInt(border);
        
        tableObject.border = border;
        tableObject.cellPadding = cellSpacing;
        tableObject.cellSpacing = cellPadding;
        if (align) 
            tableObject.align = align;
    },
    
    /**
     * 还原因单击，双击或其它交互引起的任何控件格式的改变
     * 通常运用于FireFox等非IE内核的浏览器
     * @method refreshControl
     * @return void
     */
    refreshControl: function(){
        var sel;
        if (window.getSelection) {
            sel = window.getSelection();
        }
        else 
            if (document.getSelection) {
                sel = document.getSelection();
            }
            else 
                if (document.selection) {
                    sel = document.selection;
                }
        
        if (sel) {
            if (sel.empty) {
                sel.empty();
            }
            else 
                if (sel.removeAllRanges) {
                    sel.removeAllRanges();
                }
                else 
                    if (sel.collapse) {
                        sel.collapse();
                    }
        }
    },
    
    /**
     * @method toString
     * @return String
     */
    toString: function(){
        return '[Object:RINDEX.Utility]';
    }
    
};

/*==============================================================================================*/

/**
 * @class RINDEX.Lang
 * @static
 */
RINDEX.Lang = {
	
	/**
	 * 检查指定的对象是否是数组
	 * @param {Object} input 要检查的对象
	 * @return Boolean
	 */
	isArray : function(input) {
		if (input && input.slice &&input.push)
			return true;
		return false;
	},
	
	/**
	 * 检查指定的对象是否是数字
	 * @param {Object} input 要检查的对象
	 * @return Boolean
	 */
	isNumber : function(input) {
		return typeof input == 'number' && isFinite(input);
	},
	
	/**
	 * 从父类复制方法到指定的子类
	 * @param subClass {Function}  子类
	 * @param superClass {Function} 父类
	 */
	extend : function(subClass, superClass) {
		if (!subClass||!superClass) {
            throw new Error("Call RINDEX.Lang.extend failed, not all arguments are included.");
        }
        var F = function() {};
        F.prototype=superClass.prototype;
        subClass.prototype=new F();
        subClass.prototype.constructor=subClass;
        subClass.superclass=superClass.prototype;
        if (superClass.prototype.constructor == Object.prototype.constructor) {
            superClass.prototype.constructor=superClass;
        }
	},
	
	/**
	 * @private
	 */
	toString : function() {
		return '[RINDEX.Lang]';
	}

	
};

/*==============================================================================================*/

/**
 * 可以用来表示一个平面坐标中某一特定位置的类
 * @class RINDEX.Position
 * @param {number} x X坐标
 * @param {number} y Y坐标
 */
RINDEX.Position = function(x,y) {
	
	/**
	 * X坐标
	 * @field x
	 * @type Number
	 */
	this.x = x;
	
	/**
	 * Y坐标
	 * @field y
	 * @type Number
	 */
	this.y = y;
	
	if(!RINDEX.Lang.isNumber(this.x))
		this.x = 0;
	if(!RINDEX.Lang.isNumber(this.y))
		this.y = 0;
		
};
